summaryrefslogtreecommitdiff
path: root/src/network/core/tcp_game.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/network/core/tcp_game.cpp')
-rw-r--r--src/network/core/tcp_game.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/network/core/tcp_game.cpp b/src/network/core/tcp_game.cpp
index 258f9c6b2..6c68217fc 100644
--- a/src/network/core/tcp_game.cpp
+++ b/src/network/core/tcp_game.cpp
@@ -34,7 +34,7 @@ NetworkGameSocketHandler::NetworkGameSocketHandler(SOCKET s)
}
/**
* Functions to help NetworkRecv_Packet/NetworkSend_Packet a bit
* A socket can make errors. When that happens this handles what to do.
* For clients: close connection and drop back to main-menu
* For servers: close connection and that is it
@@ -136,10 +136,10 @@ NetworkRecvStatus NetworkGameSocketHandler::HandlePacket(Packet *p)
* HandlePacket is returned.
* @return #NetworkRecvStatus of the last handled packet.
*/
-NetworkRecvStatus NetworkGameSocketHandler::Recv_Packets()
+NetworkRecvStatus NetworkGameSocketHandler::ReceivePackets()
{
Packet *p;
- while ((p = this->Recv_Packet()) != NULL) {
+ while ((p = this->ReceivePacket()) != NULL) {
NetworkRecvStatus res = HandlePacket(p);
delete p;
if (res != NETWORK_RECV_STATUS_OKAY) return res;
@@ -34,7 +34,7 @@ NetworkGameSocketHandler::NetworkGameSocketHandler(SOCKET s)
}
/**
- * Functions to help NetworkRecv_Packet/NetworkSend_Packet a bit
+ * Functions to help ReceivePacket/SendPacket a bit
* A socket can make errors. When that happens this handles what to do.
* For clients: close connection and drop back to main-menu